==> flink-walkthrough-table-java-1.10.0-sources.jar: archetype-resources/src/main/java/SpendReport.java <==
/*
 * Licensed to the Apache Software Foundation (ASF) under one
 * or more contributor license agreements.  See the NOTICE file
 * distributed with this work for additional information
 * regarding copyright ownership.  The ASF licenses this file
 * to you under the Apache License, Version 2.0 (the
 * "License"); you may not use this file except in compliance
 * with the License.  You may obtain a copy of the License at
 *
 *     http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */

package ${package};

import org.apache.flink.api.java.ExecutionEnvironment;
import org.apache.flink.table.api.java.BatchTableEnvironment;
import org.apache.flink.walkthrough.common.table.SpendReportTableSink;
import org.apache.flink.walkthrough.common.table.BoundedTransactionTableSource;
import org.apache.flink.walkthrough.common.table.TruncateDateToHour;

/**
 * Skeleton code for the table walkthrough
 */
public class SpendReport {
	public static void main(String[] args) throws Exception {
		ExecutionEnvironment env   = ExecutionEnvironment.getExecutionEnvironment();
		BatchTableEnvironment tEnv = BatchTableEnvironment.create(env);

		tEnv.registerTableSource("transactions", new BoundedTransactionTableSource());
		tEnv.registerTableSink("spend_report", new SpendReportTableSink());
		tEnv.registerFunction("truncateDateToHour", new TruncateDateToHour());

		tEnv
			.scan("transactions")
			.insertInto("spend_report");

		env.execute("Spend Report");
	}
}

==> flink-walkthrough-table-java-1.11.1-sources.jar: archetype-resources/src/main/java/SpendReport.java <==
/*
 * Licensed to the Apache Software Foundation (ASF) under one
 * or more contributor license agreements.  See the NOTICE file
 * distributed with this work for additional information
 * regarding copyright ownership.  The ASF licenses this file
 * to you under the Apache License, Version 2.0 (the
 * "License"); you may not use this file except in compliance
 * with the License.  You may obtain a copy of the License at
 *
 *     http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */

package ${package};

import org.apache.flink.api.java.ExecutionEnvironment;
import org.apache.flink.table.api.internal.TableEnvironmentInternal;
import org.apache.flink.table.api.bridge.java.BatchTableEnvironment;
import org.apache.flink.walkthrough.common.table.SpendReportTableSink;
import org.apache.flink.walkthrough.common.table.BoundedTransactionTableSource;
import org.apache.flink.walkthrough.common.table.TruncateDateToHour;

/**
 * Skeleton code for the table walkthrough
 */
public class SpendReport {
	public static void main(String[] args) throws Exception {
		ExecutionEnvironment env   = ExecutionEnvironment.getExecutionEnvironment();
		BatchTableEnvironment tEnv = BatchTableEnvironment.create(env);

		((TableEnvironmentInternal) tEnv).registerTableSourceInternal(
				"transactions", new BoundedTransactionTableSource());
		((TableEnvironmentInternal) tEnv).registerTableSinkInternal(
				"spend_report", new SpendReportTableSink());
		tEnv.registerFunction("truncateDateToHour", new TruncateDateToHour());

		tEnv
			.scan("transactions")
			.insertInto("spend_report");

		tEnv.execute("Spend Report");
	}
}
